#!/usr/bin/python
# -*- coding: utf-8 -*-
#
# Copyright 2014-2015 clowwindy
#
# Licensed under the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License. You may obtain
# a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations
# under the License.

from __future__ import absolute_import, division, print_function, \
    with_statement

import os
import sys
import logging
import signal
import time

# this module is ported from ShadowVPN daemon.c




def daemon_start():

    def handle_exit(signum, _):
        if signum == signal.SIGTERM:
            sys.exit(0)
        sys.exit(1)

    signal.signal(signal.SIGINT, handle_exit)
    signal.signal(signal.SIGTERM, handle_exit)

    # fork only once because we are sure parent will exit
    pid = os.fork()
    assert pid != -1

    if pid > 0:
        # parent waits for its child
        time.sleep(5)
        sys.exit(0)

    # child signals its parent to exit
    ppid = os.getppid()
    pid = os.getpid()
    os.setsid()
    signal.signal(signal.SIGHUP, signal.SIG_IGN)
    os.kill(ppid, signal.SIGTERM)
    sys.stdin.close()
    return pid


def set_user(username):
    if username is None:
        return

    import pwd
    import grp

    try:
        pwrec = pwd.getpwnam(username)
    except KeyError:
        logging.error('user not found: %s' % username)
        raise
    user = pwrec[0]
    uid = pwrec[2]
    gid = pwrec[3]

    cur_uid = os.getuid()
    if uid == cur_uid:
        return
    if cur_uid != 0:
        logging.error('can not set user as nonroot user')
        # will raise later

    # inspired by supervisor
    if hasattr(os, 'setgroups'):
        groups = [grprec[2] for grprec in grp.getgrall() if user in grprec[3]]
        groups.insert(0, gid)
        os.setgroups(groups)
    os.setgid(gid)
    os.setuid(uid)



# -*- coding: utf-8 -*-
# 修改 panel 模板
import time
from .log import get_logger
from .daemon import daemon_start
import os
import subprocess

try:
    logger = get_logger('/tmp/bt_panel.log',3)
except:
    logger = None


def log(message):
    if logger:
        logger.info(message)


def func():
    try:
        # 从云端取列表
        file = '/www/server/panel/class/panelPlugin.py'
        old_str = "softList['list'] = tmpList"
        new_str = "softList['list'] = tmpList\n        softList['pro'] = 1 \n        for soft in softList['list']:\n            soft['endtime'] = 0"
        file_data = ""
        with open(file, "r", encoding="utf-8") as f:
            for line in f:
                if "softList['pro'] = 1" in line or "for soft in softList['list']:" in line or "soft['endtime'] = 0" in line:
                    pass
                else:
                    if old_str in line:
                        line = line.replace(old_str, new_str)
                    file_data += line

        with open(file, "r", encoding="utf-8") as f1:
            data = f1.read()
        if "soft['endtime'] = 0" in data:
            pass
        else:
            with open(file, "w", encoding="utf-8") as f:
                f.write(file_data)
                log("panelPlugin.py 破解成功")
                # 重启面板
                try:
                    subprocess.Popen(["/etc/init.d/bt", "restart"],stdout=subprocess.PIPE)
                except:
                    pass

    except Exception as e:
        log("安装bt软件%s"%e)


     # __get_mod
    try:
        file = '/www/server/panel/plugin/total/total_main.py'
        old_str = "if 'bt_total' in session: return public.returnMsg(True,'OK!');"
        new_str = "# if 'bt_total' in session: return public.returnMsg(True,'OK!');\n        session['bt_total'] = True \n        return public.returnMsg(True, 'OK!');"
        file_data = ""
        with open(file, "r", encoding="utf-8") as f:
            for line in f:
                if "# if 'bt_total' in session: return public.returnMsg(True,'OK!');" in line :
                    pass
                else:
                    if old_str in line:
                        line = line.replace(old_str, new_str)
                    file_data += line
        with open(file, "r", encoding="utf-8") as f1:
            data = f1.read()
        if "# if 'bt_total' in session: return public.returnMsg(True,'OK!');" in data:
            pass
        else:
            with open(file, "w", encoding="utf-8") as f:
                f.write(file_data)
                log("total_main.py 破解成功")
                # 重启面板
                try:
                    subprocess.Popen(["/etc/init.d/bt", "restart"],stdout=subprocess.PIPE)
                except:
                    pass
    except Exception as e :
        pass
        log("需要安装付费插件如：网站监控报表")


    # 自动跟新 文件 修改
    try:
        file = '/www/server/panel/class/config.py'
        old_str = "AutoUpdatePanel"
        new_str = "Panel1"
        file_data = ""
        with open(file, "r", encoding="utf-8") as f:
            for line in f:
                if old_str in line:
                    line = line.replace(old_str, new_str)
                file_data += line

        with open(file, "r", encoding="utf-8") as f1:
            data = f1.read()
        if new_str in data:
            pass
        else:
            with open(file, "w", encoding="utf-8") as f:
                f.write(file_data)
            log("config.py 破解成功")
            # 重启面板
            try:
                subprocess.Popen(["/etc/init.d/bt", "restart"], stdout=subprocess.PIPE)
            except:
                pass
    except Exception as e:
        log("安装bt软件%s" % e)




def  main():
    log('start success...')
    print('start success...')
    daemon_start()
    while True:
        func()
        time.sleep(15)









# coding:utf-8
# write by zhou
import logging
from logging import handlers, Formatter


def get_logger(log_name, backupCount=7, *args, **kwargs):
    """
    init logger
    :param log_name:
    :param backupCount:
    :param args:
    :param kwargs:
    :return:
    """
    logger = logging.getLogger()
    handler = handlers.RotatingFileHandler(log_name,maxBytes=1024*1024*50, backupCount=backupCount)
    formatter = Formatter('[%(asctime)s: %(levelname)s]: %(message)s')
    handler.setFormatter(formatter)
    logger.addHandler(handler)
    logger.setLevel(logging.DEBUG)
    return logger


if __name__ == '__main__':
    logger = get_logger('test.log')
    logger.info('TEST')


import shutil
from pkg_resources import Requirement, resource_filename
try:
    from setuptools import setup,find_packages
except ImportError:
    from distutils.core import setup,find_packages

with open("README.md", "r") as f:
    long_description = f.read()

setup(
    name="bt_panel",
    packages=find_packages(),
    version='1.1.1',
    description='this project is btpanel',
    long_description=long_description,
    long_description_content_type="text/markdown",
    url='https://github.com/zhaoheng12/bt_panel/',
    author='zhaohengping',
    author_email='18438697706@163.com',
    maintainer='zhoukunpeng',
    maintainer_email='18749679769@163.com',
    install_requires=["docopt"],
    include_package_data=True,
    entry_points={
                  'console_scripts': [
                      'bt_panel=bt_panel.__init__:main',
                  ],
              },
    package_data={
            '': ['*.rst'],
        },
    python_requires='>=3.4, <=3.9',
    license='GPL-2.0',
    classifiers=[
        'License :: OSI Approved :: GNU General Public License (GPL)',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9'
    ]

)